@@ -19,7 +19,7 @@ from math import pi
 import sys
 
 ################
-VERSION="1.0.7"
+VERSION="1.0.8"
 ################
 
 verbosity = None
@@ -248,7 +248,7 @@ def createFolder(folder, parent_folder, verbosity):
     @printEvent("| | Creating {} folder...".format(folder), "| | done", 1)
     def createThisFolder(parent_folder, verbosity):
         (parent_folder/folder).mkdir(parents=True)
-    createThisFolder()
+    createThisFolder(parent_folder, verbosity)
 
 @printEvent("| | Checking save ID...", "| | done", 1)
 def polishID(id, verbosity):
